@@ -59,9 +59,10 @@ apidoc_excluded_paths = [
 ]
 apidoc_separate_modules = True
 
-repository_name = 'openstack/ironic'
-use_storyboard = True
-openstack_projects = [
+openstackdocs_repo_name = 'openstack/ironic'
+openstackdocs_use_storyboard = True
+openstackdocs_pdf_link = True
+openstackdocs_projects = [
     'bifrost',
     'cinder',
     'glance',
@@ -124,7 +125,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # A list of glob-style patterns that should be excluded when looking for
 # source files. They are matched against the source file names relative to the
