@@ -664,6 +664,10 @@ class AgentConnectionFailed(IronicException):
     _msg_fmt = _("Connection to agent failed: %(reason)s")
 
 
+class AgentCommandTimeout(IronicException):
+    _msg_fmt = _("Timeout executing command %(command)s on node %(node)s")
+
+
 class NodeProtected(HTTPForbidden):
     _msg_fmt = _("Node %(node)s is protected and cannot be undeployed, "
                  "rebuilt or deleted")
