@@ -15,10 +15,11 @@
 This client is compatible with any JSON RPC 2.0 implementation, including ours.
 """
 
+import base64
+
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import importutils
-from oslo_utils import netutils
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 
@@ -37,15 +38,27 @@ def _get_session():
     global _SESSION
 
     if _SESSION is None:
-        if json_rpc.require_authentication():
+        auth_strategy = json_rpc.auth_strategy()
+        if auth_strategy == 'keystone':
             auth = keystone.get_auth('json_rpc')
         else:
             auth = None
 
-        _SESSION = keystone.get_session('json_rpc', auth=auth)
-        _SESSION.headers = {
+        session = keystone.get_session('json_rpc', auth=auth)
+        headers = {
             'Content-Type': 'application/json'
         }
+        if auth_strategy == 'http_basic':
+            token = '{}:{}'.format(
+                CONF.json_rpc.http_basic_username,
+                CONF.json_rpc.http_basic_password
+            ).encode('utf-8')
+            encoded = base64.b64encode(token).decode('utf-8')
+            headers['Authorization'] = 'Basic {}'.format(encoded)
+
+        # Adds options like connect_retries
+        _SESSION = keystone.get_adapter('json_rpc', session=session,
+                                        additional_headers=headers)
 
     return _SESSION
 
@@ -154,12 +167,7 @@ class _CallContext(object):
             body['id'] = context.request_id or uuidutils.generate_uuid()
 
         LOG.debug("RPC %s with %s", method, strutils.mask_dict_password(body))
-        scheme = 'http'
-        if CONF.json_rpc.use_ssl:
-            scheme = 'https'
-        url = '%s://%s:%d' % (scheme,
-                              netutils.escape_ipv6(self.host),
-                              CONF.json_rpc.port)
+        url = 'http://%s:%d' % (self.host, CONF.json_rpc.port)
         result = _get_session().post(url, json=body)
         LOG.debug('RPC %s returned %s', method,
                   strutils.mask_password(result.text or '<None>'))
