@@ -444,23 +444,16 @@ def cleaning_error_handler(task, msg, tear_down_cleaning=True,
         task.process_event('fail', target_state=target_state)
 
 
-def wipe_token_and_url(task):
-    """Remove agent URL and token from the task."""
-    info = task.node.driver_internal_info
-    info.pop('agent_secret_token', None)
-    info.pop('agent_secret_token_pregenerated', None)
-    # Remove agent_url since it will be re-asserted
-    # upon the next deployment attempt.
-    info.pop('agent_url', None)
-    task.node.driver_internal_info = info
-
-
 def wipe_deploy_internal_info(task):
     """Remove temporary deployment fields from driver_internal_info."""
-    if not fast_track_able(task):
-        wipe_token_and_url(task)
-    # Clear any leftover metadata about deployment.
     info = task.node.driver_internal_info
+    if not fast_track_able(task):
+        info.pop('agent_secret_token', None)
+        info.pop('agent_secret_token_pregenerated', None)
+        # Remove agent_url since it will be re-asserted
+        # upon the next deployment attempt.
+        info.pop('agent_url', None)
+    # Clear any leftover metadata about deployment.
     info['deploy_steps'] = None
     info.pop('agent_cached_deploy_steps', None)
     info.pop('deploy_step_index', None)
@@ -473,9 +466,11 @@ def wipe_deploy_internal_info(task):
 
 def wipe_cleaning_internal_info(task):
     """Remove temporary cleaning fields from driver_internal_info."""
-    if not fast_track_able(task):
-        wipe_token_and_url(task)
     info = task.node.driver_internal_info
+    if not fast_track_able(task):
+        info.pop('agent_url', None)
+        info.pop('agent_secret_token', None)
+        info.pop('agent_secret_token_pregenerated', None)
     info['clean_steps'] = None
     info.pop('agent_cached_clean_steps', None)
     info.pop('clean_step_index', None)
@@ -977,11 +972,25 @@ def is_fast_track(task):
     :returns: True if the last heartbeat that was recorded was within
               the [deploy]fast_track_timeout setting.
     """
-    return (fast_track_able(task)
-            and value_within_timeout(
-                task.node.driver_internal_info.get('agent_last_heartbeat'),
-                CONF.deploy.fast_track_timeout)
-            and task.driver.power.get_power_state(task) == states.POWER_ON)
+    if (not fast_track_able(task)
+            or task.driver.power.get_power_state(task) != states.POWER_ON):
+        if task.node.last_error:
+            LOG.debug('Node %(node)s is not fast-track-able because it has '
+                      'an error: %(error)s',
+                      {'node': task.node.uuid, 'error': task.node.last_error})
+        return False
+
+    if value_within_timeout(
+            task.node.driver_internal_info.get('agent_last_heartbeat'),
+            CONF.deploy.fast_track_timeout):
+        return True
+    else:
+        LOG.debug('Node %(node)s should be fast-track-able, but the agent '
+                  'doesn\'t seem to be running. Last heartbeat: %(last)s',
+                  {'node': task.node.uuid,
+                   'last': task.node.driver_internal_info.get(
+                       'agent_last_heartbeat')})
+        return False
 
 
 def remove_agent_url(node):
@@ -1154,3 +1163,30 @@ def hash_password(password=''):
     :param value: Value to be hashed
     """
     return crypt.crypt(password, make_salt())
+
+
+def get_attached_vif(port):
+    """Get any attached vif ID for the port
+
+    :param port: The port object upon which to check for a vif
+                 record.
+    :returns: Returns a tuple of the vif if found and the use of
+              the vif in the form of a string, 'tenant', 'cleaning'
+              'provisioning', 'rescuing'.
+    :raises: InvalidState exception upon finding a port with a
+             transient state vif on the port.
+    """
+
+    tenant_vif = port.internal_info.get('tenant_vif_port_id')
+    if tenant_vif:
+        return (tenant_vif, 'tenant')
+    clean_vif = port.internal_info.get('cleaning_vif_port_id')
+    if clean_vif:
+        return (clean_vif, 'cleaning')
+    prov_vif = port.internal_info.get('provisioning_vif_port_id')
+    if prov_vif:
+        return (prov_vif, 'provisioning')
+    rescue_vif = port.internal_info.get('rescuing_vif_port_id')
+    if rescue_vif:
+        return (rescue_vif, 'rescuing')
+    return (None, None)
