@@ -58,10 +58,15 @@ api_opts = [
         default='keystone',
         choices=[('noauth', _('no authentication')),
                  ('keystone', _('use the Identity service for '
-                                'authentication'))],
+                                'authentication')),
+                 ('http_basic', _('HTTP basic authentication'))],
         help=_('Authentication strategy used by ironic-api. "noauth" should '
                'not be used in a production environment because all '
                'authentication will be disabled.')),
+    cfg.StrOpt('http_basic_auth_user_file',
+               default='/etc/ironic/htpasswd',
+               help=_('Path to Apache format user authentication file used '
+                      'when auth_strategy=http_basic')),
     cfg.BoolOpt('debug_tracebacks_in_api',
                 default=False,
                 help=_('Return server tracebacks in the API response for any '
@@ -72,6 +77,7 @@ api_opts = [
                 help=_('Enable pecan debug mode. WARNING: this is insecure '
                        'and should not be used in a production environment.')),
     cfg.StrOpt('default_resource_class',
+               mutable=True,
                help=_('Resource class to use for new nodes when no resource '
                       'class is provided in the creation request.')),
 ]
@@ -152,18 +158,9 @@ driver_opts = [
 ]
 
 exc_log_opts = [
-    cfg.BoolOpt('fatal_exception_format_errors',
-                default=False,
-                help=_('Used if there is a formatting error when generating '
-                       'an exception message (a programming error). If True, '
-                       'raise an exception; if False, use the unformatted '
-                       'message.'),
-                deprecated_for_removal=True,
-                deprecated_reason=_('Same option in the ironic_lib section '
-                                    'should be used instead.')),
     cfg.IntOpt('log_in_db_max_size', default=4096,
                help=_('Max number of characters of any node '
-                      'last_error/maintenance_reason pushed to database.')),
+                      'last_error/maintenance_reason pushed to database.'))
 ]
 
 hash_opts = [
@@ -191,6 +188,7 @@ hash_opts = [
 image_opts = [
     cfg.BoolOpt('force_raw_images',
                 default=True,
+                mutable=True,
                 help=_('If True, convert backing images to "raw" disk image '
                        'format.')),
     cfg.StrOpt('isolinux_bin',
@@ -231,6 +229,7 @@ image_opts = [
 img_cache_opts = [
     cfg.BoolOpt('parallel_image_downloads',
                 default=False,
+                mutable=True,
                 help=_('Run image downloads and raw format conversions in '
                        'parallel.')),
 ]
@@ -304,6 +303,7 @@ path_opts = [
 portgroup_opts = [
     cfg.StrOpt(
         'default_portgroup_mode', default='active-backup',
+        mutable=True,
         help=_(
             'Default mode for portgroups. Allowed values can be found in the '
             'linux kernel documentation on bonding: '
@@ -340,6 +340,7 @@ service_opts = [
                       'conductor and API services')),
     cfg.BoolOpt('require_agent_token',
                 default=False,
+                mutable=True,
                 help=_('Used to require the use of agent tokens. These '
                        'tokens are used to guard the api lookup endpoint and '
                        'conductor heartbeat processing logic to authenticate '
