@@ -19,7 +19,6 @@ from oslo_log import log
 from oslo_utils import excutils
 from oslo_utils import units
 
-from ironic.common import dhcp_factory
 from ironic.common import exception
 from ironic.common.glance_service import service_utils
 from ironic.common.i18n import _
@@ -32,6 +31,7 @@ from ironic.conductor import utils as manager_utils
 from ironic.conf import CONF
 from ironic.drivers import base
 from ironic.drivers.modules import agent_base
+from ironic.drivers.modules import agent_client
 from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules import deploy_utils
 
@@ -256,6 +256,7 @@ class AgentDeployMixin(agent_base.AgentDeployMixin):
 
         task.process_event('wait')
 
+    # TODO(dtantsur): remove in W
     def _get_uuid_from_result(self, task, type_uuid):
         command = self._client.get_commands_status(task.node)[-1]
 
@@ -283,7 +284,7 @@ class AgentDeployMixin(agent_base.AgentDeployMixin):
         # the prepare_image command is complete
         command = self._client.get_commands_status(node)[-1]
         if command['command_status'] == 'FAILED':
-            return command['command_error']
+            return agent_client.get_command_error(command)
 
     @METRICS.timer('AgentDeployMixin.reboot_to_instance')
     def reboot_to_instance(self, task):
@@ -315,39 +316,47 @@ class AgentDeployMixin(agent_base.AgentDeployMixin):
         # ppc64* hardware we need to provide the 'PReP_Boot_partition_uuid' to
         # direct where the bootloader should be installed.
         driver_internal_info = task.node.driver_internal_info
-        root_uuid = self._get_uuid_from_result(task, 'root_uuid')
+        try:
+            partition_uuids = self._client.get_partition_uuids(node).get(
+                'command_result') or {}
+            root_uuid = partition_uuids.get('root uuid')
+        except exception.AgentAPIError:
+            # TODO(dtantsur): remove in W
+            LOG.warning('Old ironic-python-agent detected, please update '
+                        'to Victoria or newer')
+            partition_uuids = None
+            root_uuid = self._get_uuid_from_result(task, 'root_uuid')
+
         if root_uuid:
             driver_internal_info['root_uuid_or_disk_id'] = root_uuid
             task.node.driver_internal_info = driver_internal_info
             task.node.save()
-        elif iwdi and CONF.agent.manage_agent_boot:
-            # IPA version less than 3.1.0 will not return root_uuid for
-            # whole disk image. Also IPA version introduced a requirement
-            # for hexdump utility that may not be always available. Need to
-            # fall back to older behavior for the same.
-            LOG.warning("With the deploy ramdisk based on Ironic Python Agent "
-                        "version 3.1.0 and beyond, the drivers using "
-                        "`direct` deploy interface performs `netboot` or "
-                        "`local` boot for whole disk image based on value "
-                        "of boot option setting. When you upgrade Ironic "
-                        "Python Agent in your deploy ramdisk, ensure that "
-                        "boot option is set appropriately for the node %s. "
-                        "The boot option can be set using configuration "
-                        "`[deploy]/default_boot_option` or as a `boot_option` "
-                        "capability in node's `properties['capabilities']`. "
-                        "Also please note that this functionality requires "
-                        "`hexdump` command in the ramdisk.", node.uuid)
+        elif not iwdi:
+            LOG.error('No root UUID returned from the ramdisk for node '
+                      '%(node)s, the deploy will likely fail. Partition '
+                      'UUIDs are %(uuids)s',
+                      {'node': node.uuid, 'uuid': partition_uuids})
 
         efi_sys_uuid = None
         if not iwdi:
             if boot_mode_utils.get_boot_mode(node) == 'uefi':
-                efi_sys_uuid = (self._get_uuid_from_result(task,
-                                'efi_system_partition_uuid'))
+                # TODO(dtantsur): remove in W
+                if partition_uuids is None:
+                    efi_sys_uuid = (self._get_uuid_from_result(task,
+                                    'efi_system_partition_uuid'))
+                else:
+                    efi_sys_uuid = partition_uuids.get(
+                        'efi system partition uuid')
 
         prep_boot_part_uuid = None
         if cpu_arch is not None and cpu_arch.startswith('ppc64'):
-            prep_boot_part_uuid = (self._get_uuid_from_result(task,
-                                   'PReP_Boot_partition_uuid'))
+            # TODO(dtantsur): remove in W
+            if partition_uuids is None:
+                prep_boot_part_uuid = (self._get_uuid_from_result(task,
+                                       'PReP_Boot_partition_uuid'))
+            else:
+                prep_boot_part_uuid = partition_uuids.get(
+                    'PReP Boot partition uuid')
 
         LOG.info('Image successfully written to node %s', node.uuid)
 
@@ -371,7 +380,8 @@ class AgentDeployMixin(agent_base.AgentDeployMixin):
         self.reboot_and_finish_deploy(task)
 
 
-class AgentDeploy(AgentDeployMixin, base.DeployInterface):
+class AgentDeploy(AgentDeployMixin, agent_base.AgentBaseMixin,
+                  base.DeployInterface):
     """Interface for deploy-related actions."""
 
     def get_properties(self):
@@ -381,6 +391,10 @@ class AgentDeploy(AgentDeployMixin, base.DeployInterface):
         """
         return COMMON_PROPERTIES
 
+    def should_manage_boot(self, task):
+        """Whether agent boot is managed by ironic."""
+        return CONF.agent.manage_agent_boot
+
     @METRICS.timer('AgentDeploy.validate')
     def validate(self, task):
         """Validate the driver-specific Node deployment info.
@@ -499,31 +513,6 @@ class AgentDeploy(AgentDeployMixin, base.DeployInterface):
             LOG.info('Deployment to node %s done', task.node.uuid)
             return None
 
-    @METRICS.timer('AgentDeploy.tear_down')
-    @task_manager.require_exclusive_lock
-    def tear_down(self, task):
-        """Tear down a previous deployment on the task's node.
-
-        :param task: a TaskManager instance.
-        :returns: status of the deploy. One of ironic.common.states.
-        :raises: NetworkError if the cleaning ports cannot be removed.
-        :raises: InvalidParameterValue when the wrong power state is specified
-             or the wrong driver info is specified for power management.
-        :raises: StorageError when the storage interface attached volumes fail
-             to detach.
-        :raises: other exceptions by the node's power driver if something
-             wrong occurred during the power action.
-        """
-        manager_utils.node_power_action(task, states.POWER_OFF)
-        task.driver.storage.detach_volumes(task)
-        deploy_utils.tear_down_storage_configuration(task)
-        with manager_utils.power_state_for_network_configuration(task):
-            task.driver.network.unconfigure_tenant_networks(task)
-            # NOTE(mgoddard): If the deployment was unsuccessful the node may
-            # have ports on the provisioning network which were not deleted.
-            task.driver.network.remove_provisioning_network(task)
-        return states.DELETED
-
     @METRICS.timer('AgentDeploy.prepare')
     @task_manager.require_exclusive_lock
     def prepare(self, task):
@@ -649,46 +638,10 @@ class AgentDeploy(AgentDeployMixin, base.DeployInterface):
 
         :param task: a TaskManager instance.
         """
-        if CONF.agent.manage_agent_boot:
-            task.driver.boot.clean_up_ramdisk(task)
-        task.driver.boot.clean_up_instance(task)
-        provider = dhcp_factory.DHCPFactory()
-        provider.clean_dhcp(task)
+        super(AgentDeploy, self).clean_up(task)
         if CONF.agent.image_download_source == 'http':
             deploy_utils.destroy_http_instance_images(task.node)
 
-    def take_over(self, task):
-        """Take over management of this node from a dead conductor.
-
-        :param task: a TaskManager instance.
-        """
-        pass
-
-    @METRICS.timer('AgentDeploy.prepare_cleaning')
-    def prepare_cleaning(self, task):
-        """Boot into the agent to prepare for cleaning.
-
-        :param task: a TaskManager object containing the node
-        :raises: NodeCleaningFailure, NetworkError if the previous cleaning
-            ports cannot be removed or if new cleaning ports cannot be created.
-        :raises: InvalidParameterValue if cleaning network UUID config option
-            has an invalid value.
-        :returns: states.CLEANWAIT to signify an asynchronous prepare
-        """
-        return deploy_utils.prepare_inband_cleaning(
-            task, manage_boot=CONF.agent.manage_agent_boot)
-
-    @METRICS.timer('AgentDeploy.tear_down_cleaning')
-    def tear_down_cleaning(self, task):
-        """Clean up the PXE and DHCP files after cleaning.
-
-        :param task: a TaskManager object containing the node
-        :raises: NodeCleaningFailure, NetworkError if the cleaning ports cannot
-            be removed
-        """
-        deploy_utils.tear_down_inband_cleaning(
-            task, manage_boot=CONF.agent.manage_agent_boot)
-
 
 class AgentRAID(base.RAIDInterface):
     """Implementation of RAIDInterface which uses agent ramdisk."""
