@@ -31,6 +31,24 @@ METRICS = metrics_utils.get_metrics_logger(__name__)
 DEFAULT_IPA_PORTAL_PORT = 3260
 
 
+def get_command_error(command):
+    """Extract an error string from the command result.
+
+    :param command: Command information from the agent.
+    :return: Error string.
+    """
+    error = command.get('command_error')
+    if error is None:
+        LOG.error('Agent returned invalid response: missing command_error in '
+                  '%s', command)
+        return _('Invalid agent response')
+
+    if isinstance(error, dict):
+        return error.get('details') or error.get('message') or str(error)
+    else:
+        return error
+
+
 class AgentClient(object):
     """Client for interacting with nodes via a REST API."""
     @METRICS.timer('AgentClient.__init__')
@@ -56,13 +74,65 @@ class AgentClient(object):
             'params': params,
         })
 
+    def _raise_if_typeerror(self, result, node, method):
+        error = result.get('command_error')
+        if error and error.get('type') == 'TypeError':
+            LOG.error('Agent command %(method)s for node %(node)s failed. '
+                      'Internal TypeError detected: Error %(error)s',
+                      {'method': method, 'node': node.uuid, 'error': error})
+            raise exception.AgentAPIError(node=node.uuid,
+                                          status=error.get('code'),
+                                          error=get_command_error(result))
+
+    @METRICS.timer('AgentClient._wait_for_command')
+    @retrying.retry(
+        retry_on_exception=(
+            lambda e: isinstance(e, exception.AgentCommandTimeout)),
+        stop_max_attempt_number=CONF.agent.command_wait_attempts,
+        wait_fixed=CONF.agent.command_wait_interval * 1000)
+    def _wait_for_command(self, node, method):
+        """Wait for a command to complete.
+
+        :param node: A Node object.
+        :param method: A string represents the command executed by agent.
+        :raises: AgentCommandTimeout if timeout is reached.
+        """
+        try:
+            method = method.split('.', 1)[1]
+        except IndexError:
+            pass
+
+        # NOTE(dtantsur): this function uses AgentCommandTimeout on every
+        # failure, but unless the timeout is reached, the exception is caught
+        # and retried by the @retry decorator above.
+
+        commands = self.get_commands_status(node)
+        try:
+            result = next(c for c in reversed(commands)
+                          if c.get('command_name') == method)
+        except StopIteration:
+            LOG.debug('Command %(cmd)s is not in the executing commands list '
+                      'for node %(node)s',
+                      {'cmd': method, 'node': node.uuid})
+            raise exception.AgentCommandTimeout(command=method, node=node.uuid)
+
+        if result.get('command_status') == 'RUNNING':
+            LOG.debug('Command %(cmd)s has not finished yet for node %(node)s',
+                      {'cmd': method, 'node': node.uuid})
+            raise exception.AgentCommandTimeout(command=method, node=node.uuid)
+        else:
+            LOG.debug('Command %(cmd)s has finished for node %(node)s with '
+                      'result %(result)s',
+                      {'cmd': method, 'node': node.uuid, 'result': result})
+            self._raise_if_typeerror(result, node, method)
+            return result
+
     @METRICS.timer('AgentClient._command')
     @retrying.retry(
         retry_on_exception=(
             lambda e: isinstance(e, exception.AgentConnectionFailed)),
         stop_max_attempt_number=CONF.agent.max_command_attempts)
-    def _command(self, node, method, params, wait=False,
-                 command_timeout_factor=1):
+    def _command(self, node, method, params, wait=False, poll=False):
         """Sends command to agent.
 
         :param node: A Node object.
@@ -72,19 +142,16 @@ class AgentClient(object):
                        body.
         :param wait: True to wait for the command to finish executing, False
                      otherwise.
-        :param command_timeout_factor: An integer, default 1, by which to
-                                       multiply the [agent]command_timeout
-                                       value. This is intended for use with
-                                       extremely long running commands to
-                                       the agent ramdisk where a general
-                                       timeout value should not be extended
-                                       in all cases.
+        :param poll: Whether to poll the command until completion. Provides
+                     a better alternative to `wait` for long-running commands.
         :raises: IronicException when failed to issue the request or there was
                  a malformed response from the agent.
         :raises: AgentAPIError when agent failed to execute specified command.
         :returns: A dict containing command result from agent, see
                   get_commands_status for a sample.
         """
+        assert not (wait and poll)
+
         url = self._get_command_url(node)
         body = self._get_command_body(method, params)
         request_params = {
@@ -99,7 +166,7 @@ class AgentClient(object):
         try:
             response = self.session.post(
                 url, params=request_params, data=body,
-                timeout=CONF.agent.command_timeout * command_timeout_factor)
+                timeout=CONF.agent.command_timeout)
         except (requests.ConnectionError, requests.Timeout) as e:
             msg = (_('Failed to connect to the agent running on node %(node)s '
                      'for invoking command %(method)s. Error: %(error)s') %
@@ -128,40 +195,14 @@ class AgentClient(object):
             raise exception.IronicException(msg)
 
         error = result.get('command_error')
-        exc_type = None
-        if error:
-            # if an error, we should see if a type field exists. This type
-            # field may signal an exception that is compatability based.
-            exc_type = error.get('type')
-
         LOG.debug('Agent command %(method)s for node %(node)s returned '
                   'result %(res)s, error %(error)s, HTTP status code %(code)d',
                   {'node': node.uuid, 'method': method,
                    'res': result.get('command_result'),
                    'error': error,
                    'code': response.status_code})
+
         if response.status_code >= http_client.BAD_REQUEST:
-            faultstring = result.get('faultstring')
-            if 'agent_token' in faultstring and agent_token:
-                # NOTE(TheJulia) We have an agent that is out of date.
-                # which means I guess grenade updates the agent image
-                # for upgrades... :(
-                if not CONF.require_agent_token:
-                    LOG.warning('Agent command %(method)s for node %(node)s '
-                                'failed. Expected 2xx HTTP status code, got '
-                                '%(code)d. Error suggests an older ramdisk '
-                                'which does not support ``agent_token``. '
-                                'Removing the token for the next retry.',
-                                {'method': method, 'node': node.uuid,
-                                 'code': response.status_code})
-                    i_info = node.driver_internal_info
-                    i_info.pop('agent_secret_token')
-                    node.driver_internal_info = i_info
-                    node.save()
-                    msg = ('Node {} does not appear to support '
-                           'agent_token and it is not required. Next retry '
-                           'will be without the token.').format(node.uuid)
-                    raise exception.AgentConnectionFailed(reason=msg)
             LOG.error('Agent command %(method)s for node %(node)s failed. '
                       'Expected 2xx HTTP status code, got %(code)d.',
                       {'method': method, 'node': node.uuid,
@@ -169,14 +210,11 @@ class AgentClient(object):
             raise exception.AgentAPIError(node=node.uuid,
                                           status=response.status_code,
                                           error=result.get('faultstring'))
-        if exc_type == 'TypeError':
-            LOG.error('Agent command %(method)s for node %(node)s failed. '
-                      'Internal %(exc_type)s error detected: Error %(error)s',
-                      {'method': method, 'node': node.uuid,
-                       'exc_type': exc_type, 'error': error})
-            raise exception.AgentAPIError(node=node.uuid,
-                                          status=error.get('code'),
-                                          error=result.get('faultstring'))
+
+        self._raise_if_typeerror(result, node, method)
+
+        if poll:
+            result = self._wait_for_command(node, method)
 
         return result
 
@@ -237,29 +275,6 @@ class AgentClient(object):
                   {'node': node.uuid, 'status': status})
         return result
 
-    def get_last_command_status(self, node, method):
-        """Get the last status for the given command.
-
-        :param node: A Node object.
-        :param method: Command name.
-        :returns: A dict containing command status from agent or None
-            if the command was not found.
-        """
-        try:
-            method = method.split('.', 1)[1]
-        except IndexError:
-            pass
-
-        commands = self.get_commands_status(node)
-        try:
-            return next(c for c in reversed(commands)
-                        if c.get('command_name') == method)
-        except StopIteration:
-            LOG.debug('Command %(cmd)s is not in the executing commands list '
-                      'for node %(node)s',
-                      {'cmd': method, 'node': node.uuid})
-            return None
-
     @METRICS.timer('AgentClient.prepare_image')
     def prepare_image(self, node, image_info, wait=False):
         """Call the `prepare_image` method on the node.
@@ -288,7 +303,7 @@ class AgentClient(object):
         return self._command(node=node,
                              method='standby.prepare_image',
                              params=params,
-                             wait=wait)
+                             poll=wait)
 
     @METRICS.timer('AgentClient.start_iscsi_target')
     def start_iscsi_target(self, node, iqn,
@@ -356,8 +371,7 @@ class AgentClient(object):
             return self._command(node=node,
                                  method='image.install_bootloader',
                                  params=params,
-                                 wait=True,
-                                 command_timeout_factor=2)
+                                 poll=True)
         except exception.AgentAPIError:
             # NOTE(arne_wiebalck): If for software RAID and 'uefi' as the boot
             # mode, we find that the IPA does not yet support the additional
@@ -381,8 +395,7 @@ class AgentClient(object):
                 return self._command(node=node,
                                      method='image.install_bootloader',
                                      params=params,
-                                     wait=True,
-                                     command_timeout_factor=2)
+                                     poll=True)
 
     @METRICS.timer('AgentClient.get_clean_steps')
     def get_clean_steps(self, node, ports):
@@ -510,6 +523,22 @@ class AgentClient(object):
                              method='deploy.execute_deploy_step',
                              params=params)
 
+    @METRICS.timer('AgentClient.get_partition_uuids')
+    def get_partition_uuids(self, node):
+        """Get deploy steps from agent.
+
+        :param node: A node object.
+        :raises: IronicException when failed to issue the request or there was
+                 a malformed response from the agent.
+        :raises: AgentAPIError when agent failed to execute specified command.
+        :returns: A dict containing command response from agent.
+
+        """
+        return self._command(node=node,
+                             method='standby.get_partition_uuids',
+                             params={},
+                             wait=True)
+
     @METRICS.timer('AgentClient.power_off')
     def power_off(self, node):
         """Soft powers off the bare metal node by shutting down ramdisk OS.
