@@ -191,8 +191,7 @@ class PXEBaseMixin(object):
             pxe_info.update(
                 pxe_utils.get_instance_image_info(
                     task, ipxe_enabled=self.ipxe_enabled))
-
-        boot_mode_utils.sync_boot_mode(task)
+            boot_mode_utils.sync_boot_mode(task)
 
         pxe_options = pxe_utils.build_pxe_config_options(
             task, pxe_info, ipxe_enabled=self.ipxe_enabled,
@@ -201,7 +200,10 @@ class PXEBaseMixin(object):
         if ramdisk_params.get("ipa-api-url"):
             pxe_options["ipa-api-url"] = ramdisk_params["ipa-api-url"]
 
-        pxe_config_template = deploy_utils.get_pxe_config_template(node)
+        if self.ipxe_enabled:
+            pxe_config_template = deploy_utils.get_ipxe_config_template(node)
+        else:
+            pxe_config_template = deploy_utils.get_pxe_config_template(node)
 
         pxe_utils.create_pxe_config(task, pxe_options,
                                     pxe_config_template,
@@ -302,11 +304,22 @@ class PXEBaseMixin(object):
                     ipxe_enabled=self.ipxe_enabled)
                 boot_device = boot_devices.PXE
         else:
-            # If it's going to boot from the local disk, we don't need
-            # PXE config files. They still need to be generated as part
-            # of the prepare() because the deployment does PXE boot the
-            # deploy ramdisk
-            pxe_utils.clean_up_pxe_config(task, ipxe_enabled=self.ipxe_enabled)
+            # NOTE(dtantsur): create a PXE configuration as a safety net for
+            # hardware uncapable of persistent boot. If on a reboot it will try
+            # to boot from PXE, this configuration will return it back.
+            if CONF.pxe.enable_netboot_fallback:
+                pxe_utils.build_service_pxe_config(
+                    task, instance_image_info,
+                    task.node.driver_internal_info.get('root_uuid_or_disk_id'),
+                    ipxe_enabled=self.ipxe_enabled,
+                    # PXE config for whole disk images is identical to what
+                    # we need to boot from local disk, so use True even
+                    # for partition images.
+                    is_whole_disk_image=True)
+            else:
+                # Clean up the deployment configuration
+                pxe_utils.clean_up_pxe_config(
+                    task, ipxe_enabled=self.ipxe_enabled)
             boot_device = boot_devices.DISK
 
         # NOTE(pas-ha) do not re-set boot device on ACTIVE nodes
