@@ -17,6 +17,7 @@ from ironic.drivers import generic
 from ironic.drivers.modules import inspector
 from ironic.drivers.modules import ipxe
 from ironic.drivers.modules import noop
+from ironic.drivers.modules import noop_mgmt
 from ironic.drivers.modules import pxe
 from ironic.drivers.modules.redfish import bios as redfish_bios
 from ironic.drivers.modules.redfish import boot as redfish_boot
@@ -36,7 +37,7 @@ class RedfishHardware(generic.GenericHardware):
     @property
     def supported_management_interfaces(self):
         """List of supported management interfaces."""
-        return [redfish_mgmt.RedfishManagement]
+        return [redfish_mgmt.RedfishManagement, noop_mgmt.NoopManagement]
 
     @property
     def supported_power_interfaces(self):
