@@ -15,13 +15,12 @@
 #    under the License.
 
 from http import client as http_client
+from unittest import mock
 
-import mock
 import os_traits
 from oslo_config import cfg
 from oslo_utils import uuidutils
 from webob import static
-import wsme
 
 from ironic import api
 from ironic.api.controllers.v1 import node as api_node
@@ -106,18 +105,15 @@ class TestApiUtils(base.TestCase):
         # Raises a KeyError.
         doc = {}
         patch = [{"op": "remove", "path": "/foo"}]
-        self.assertRaisesRegex(exception.PatchError,
-                               "can't remove non-existent object 'foo'",
-                               utils.apply_jsonpatch, doc, patch)
+        self.assertRaises(exception.PatchError,
+                          utils.apply_jsonpatch, doc, patch)
 
     def test_apply_jsonpatch_replace_non_existent_list_item(self):
         # Raises an IndexError.
         doc = []
         patch = [{"op": "replace", "path": "/0", "value": 42}]
-        self.assertRaisesRegex(exception.PatchError,
-                               "can't replace outside of list|"
-                               "list assignment index out of range",
-                               utils.apply_jsonpatch, doc, patch)
+        self.assertRaises(exception.PatchError,
+                          utils.apply_jsonpatch, doc, patch)
 
     def test_get_patch_values_no_path(self):
         patch = [{'path': '/name', 'op': 'update', 'value': 'node-0'}]
@@ -692,7 +688,7 @@ class TestVendorPassthru(base.TestCase):
         passthru_mock.assert_called_once_with(
             'fake-context', 'fake-ident', 'squarepants', 'POST',
             'fake-data', 'fake-topic')
-        self.assertIsInstance(response, wsme.api.Response)
+        self.assertIsInstance(response, atypes.Response)
         self.assertEqual('SpongeBob', response.obj)
         self.assertEqual(response.return_type, atypes.Unset)
         sc = http_client.ACCEPTED if async_call else http_client.OK
@@ -731,7 +727,7 @@ class TestVendorPassthru(base.TestCase):
         self.assertEqual(expct_return_value,
                          mock_response.app_iter.file.read())
         # Assert response message is none
-        self.assertIsInstance(response, wsme.api.Response)
+        self.assertIsInstance(response, atypes.Response)
         self.assertIsNone(response.obj)
         self.assertIsNone(response.return_type)
         self.assertEqual(http_client.OK, response.status_code)
