@@ -12,9 +12,9 @@
 
 import copy
 import time
+from unittest import mock
 
 from keystoneauth1 import loading as kaloading
-import mock
 from neutronclient.common import exceptions as neutron_client_exc
 from neutronclient.v2_0 import client
 from oslo_utils import uuidutils
@@ -1222,19 +1222,6 @@ class TestUnbindPort(base.TestCase):
         neutron.unbind_neutron_port(port_id, context=self.context)
         mock_unp.assert_has_calls(update_calls)
 
-    def test_unbind_neutron_port_not_reset_mac(self, mock_unp):
-        port_id = 'fake-port-id'
-        body_unbind = {
-            'port': {
-                'binding:host_id': '',
-                'binding:profile': {}
-            }
-        }
-        neutron.unbind_neutron_port(port_id, context=self.context,
-                                    reset_mac=False)
-        mock_unp.assert_called_once_with(self.context, port_id, body_unbind,
-                                         None)
-
     @mock.patch.object(neutron, 'LOG', autospec=True)
     def test_unbind_neutron_port_not_found(self, mock_log, mock_unp):
         port_id = 'fake-port-id'
