@@ -17,8 +17,9 @@
 
 """Test utils for Ironic Managers."""
 
+from unittest import mock
+
 from futurist import periodics
-import mock
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 
@@ -142,7 +143,6 @@ class ServiceSetUpMixin(object):
             self.service.init_host()
         else:
             with mock.patch.object(periodics, 'PeriodicWorker', autospec=True):
-                self.service.prepare_host()
                 self.service.init_host()
         self.addCleanup(self._stop_service)
 
