@@ -17,8 +17,9 @@
 
 """Tests for :class:`ironic.conductor.task_manager`."""
 
+from unittest import mock
+
 import futurist
-import mock
 from oslo_utils import uuidutils
 
 from ironic.common import driver_factory
@@ -34,14 +35,14 @@ from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.objects import utils as obj_utils
 
 
-@mock.patch.object(objects.Node, 'get')
-@mock.patch.object(objects.Node, 'release')
-@mock.patch.object(objects.Node, 'reserve')
-@mock.patch.object(driver_factory, 'build_driver_for_task')
-@mock.patch.object(objects.Port, 'list_by_node_id')
-@mock.patch.object(objects.Portgroup, 'list_by_node_id')
-@mock.patch.object(objects.VolumeConnector, 'list_by_node_id')
-@mock.patch.object(objects.VolumeTarget, 'list_by_node_id')
+@mock.patch.object(objects.Node, 'get', autospec=True)
+@mock.patch.object(objects.Node, 'release', autospec=True)
+@mock.patch.object(objects.Node, 'reserve', autospec=True)
+@mock.patch.object(driver_factory, 'build_driver_for_task', autospec=True)
+@mock.patch.object(objects.Port, 'list_by_node_id', autospec=True)
+@mock.patch.object(objects.Portgroup, 'list_by_node_id', autospec=True)
+@mock.patch.object(objects.VolumeConnector, 'list_by_node_id', autospec=True)
+@mock.patch.object(objects.VolumeTarget, 'list_by_node_id', autospec=True)
 class TaskManagerTestCase(db_base.DbTestCase):
     def setUp(self):
         super(TaskManagerTestCase, self).setUp()
@@ -112,13 +113,7 @@ class TaskManagerTestCase(db_base.DbTestCase):
         get_voltgt_mock.return_value = mock.sentinel.voltgt1
         build_driver_mock.return_value = mock.sentinel.driver1
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_all(task):
-            return task.ports, task.portgroups, task.volume_targets, \
-                task.volume_connectors
-
         with task_manager.TaskManager(self.context, 'node-id1') as task:
-            _eval_all(task)
             reserve_mock.return_value = node2
             get_ports_mock.return_value = mock.sentinel.ports2
             get_portgroups_mock.return_value = mock.sentinel.portgroups2
@@ -126,7 +121,6 @@ class TaskManagerTestCase(db_base.DbTestCase):
             get_voltgt_mock.return_value = mock.sentinel.voltgt2
             build_driver_mock.return_value = mock.sentinel.driver2
             with task_manager.TaskManager(self.context, 'node-id2') as task2:
-                _eval_all(task2)
                 self.assertEqual(self.context, task.context)
                 self.assertEqual(self.node, task.node)
                 self.assertEqual(mock.sentinel.ports1, task.ports)
@@ -238,18 +232,16 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_ports_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_ports(task):
-            return task.ports
-
-        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
-            self.assertRaises(exception.IronicException, _eval_ports, task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id')
 
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_ports_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(build_driver_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
 
@@ -260,19 +252,16 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_portgroups_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_portgroups(task):
-            return task.portgroups
-
-        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
-            self.assertRaises(exception.IronicException, _eval_portgroups,
-                              task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id')
 
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(build_driver_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
 
@@ -283,18 +272,15 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_volconn_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_volconn(task):
-            return task.volume_connectors
-
-        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
-            self.assertRaises(exception.IronicException, _eval_volconn,
-                              task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id')
 
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_volconn_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(get_voltgt_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
@@ -306,17 +292,15 @@ class TaskManagerTestCase(db_base.DbTestCase):
         reserve_mock.return_value = self.node
         get_voltgt_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_voltgt(task):
-            return task.volume_targets
-
-        with task_manager.TaskManager(self.context, 'fake-node-id') as task:
-            self.assertRaises(exception.IronicException, _eval_voltgt, task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id')
 
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
         get_voltgt_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(build_driver_mock.called)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
@@ -337,10 +321,8 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         reserve_mock.assert_called_once_with(self.context, self.host,
                                              'fake-node-id')
-        self.assertFalse(get_ports_mock.called)
-        self.assertFalse(get_portgroups_mock.called)
-        self.assertFalse(get_volconn_mock.called)
-        self.assertFalse(get_voltgt_mock.called)
+        get_ports_mock.assert_called_once_with(self.context, self.node.id)
+        get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
         build_driver_mock.assert_called_once_with(mock.ANY)
         release_mock.assert_called_once_with(self.context, self.host,
                                              self.node.id)
@@ -400,19 +382,17 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_ports_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_ports(task):
-            return task.ports
-
-        with task_manager.TaskManager(self.context, 'fake-node-id',
-                                      shared=True) as task:
-            self.assertRaises(exception.IronicException, _eval_ports, task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id',
+                          shared=True)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_ports_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(build_driver_mock.called)
 
     def test_shared_lock_get_portgroups_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -421,20 +401,17 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_portgroups_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_portgroups(task):
-            return task.portgroups
-
-        with task_manager.TaskManager(self.context, 'fake-node-id',
-                                      shared=True) as task:
-            self.assertRaises(exception.IronicException, _eval_portgroups,
-                              task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id',
+                          shared=True)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(build_driver_mock.called)
 
     def test_shared_lock_get_volconn_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -443,19 +420,17 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_volconn_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_volconn(task):
-            return task.volume_connectors
-
-        with task_manager.TaskManager(self.context, 'fake-node-id',
-                                      shared=True) as task:
-            self.assertRaises(exception.IronicException, _eval_volconn, task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id',
+                          shared=True)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_volconn_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(get_voltgt_mock.called)
 
     def test_shared_lock_get_voltgt_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -464,19 +439,17 @@ class TaskManagerTestCase(db_base.DbTestCase):
         node_get_mock.return_value = self.node
         get_voltgt_mock.side_effect = exception.IronicException('foo')
 
-        # Note(arne_wiebalck): Force loading of lazy-loaded properties.
-        def _eval_voltgt(task):
-            return task.volume_targets
-
-        with task_manager.TaskManager(self.context, 'fake-node-id',
-                                      shared=True) as task:
-            self.assertRaises(exception.IronicException, _eval_voltgt, task)
+        self.assertRaises(exception.IronicException,
+                          task_manager.TaskManager,
+                          self.context,
+                          'fake-node-id',
+                          shared=True)
 
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
         get_voltgt_mock.assert_called_once_with(self.context, self.node.id)
-        self.assertTrue(build_driver_mock.called)
+        self.assertFalse(build_driver_mock.called)
 
     def test_shared_lock_build_driver_exception(
             self, get_voltgt_mock, get_volconn_mock, get_portgroups_mock,
@@ -495,10 +468,10 @@ class TaskManagerTestCase(db_base.DbTestCase):
         self.assertFalse(reserve_mock.called)
         self.assertFalse(release_mock.called)
         node_get_mock.assert_called_once_with(self.context, 'fake-node-id')
-        self.assertFalse(get_ports_mock.called)
-        self.assertFalse(get_portgroups_mock.called)
-        self.assertFalse(get_voltgt_mock.called)
-        self.assertFalse(get_volconn_mock.called)
+        get_ports_mock.assert_called_once_with(self.context, self.node.id)
+        get_portgroups_mock.assert_called_once_with(self.context, self.node.id)
+        get_volconn_mock.assert_called_once_with(self.context, self.node.id)
+        get_voltgt_mock.assert_called_once_with(self.context, self.node.id)
         build_driver_mock.assert_called_once_with(mock.ANY)
 
     def test_upgrade_lock(
@@ -700,7 +673,7 @@ class TaskManagerTestCase(db_base.DbTestCase):
         on_error_handler.assert_called_once_with(expected_exception,
                                                  'fake-argument')
 
-    @mock.patch.object(states.machine, 'copy')
+    @mock.patch.object(states.machine, 'copy', autospec=True)
     def test_init_prepares_fsm(
             self, copy_mock, get_volconn_mock, get_voltgt_mock,
             get_portgroups_mock, get_ports_mock,
