@@ -21,9 +21,9 @@ import io
 import os
 import shutil
 import tempfile
+from unittest import mock
 
 from ironic_lib import utils as ironic_utils
-import mock
 from oslo_config import cfg
 from oslo_utils import importutils
 from oslo_utils import uuidutils
