@@ -26,9 +26,9 @@ import string
 import subprocess
 import tempfile
 import time
+from unittest import mock
 
 from ironic_lib import utils as ironic_utils
-import mock
 from oslo_config import cfg
 from oslo_service import loopingcall
 from oslo_utils import netutils
