@@ -16,9 +16,9 @@
 
 import os
 import tempfile
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_config import cfg
 from oslo_utils import fileutils
 from oslo_utils import uuidutils
@@ -582,6 +582,34 @@ class GetPxeBootConfigTestCase(db_base.DbTestCase):
         result = utils.get_pxe_boot_file(self.node)
         self.assertEqual('bios-bootfile', result)
 
+    def test_get_ipxe_boot_file(self):
+        self.config(ipxe_bootfile_name='meow', group='pxe')
+        result = utils.get_ipxe_boot_file(self.node)
+        self.assertEqual('meow', result)
+
+    def test_get_ipxe_boot_file_uefi(self):
+        self.config(uefi_ipxe_bootfile_name='ipxe-uefi-bootfile', group='pxe')
+        properties = {'capabilities': 'boot_mode:uefi'}
+        self.node.properties = properties
+        result = utils.get_ipxe_boot_file(self.node)
+        self.assertEqual('ipxe-uefi-bootfile', result)
+
+    def test_get_ipxe_boot_file_other_arch(self):
+        arch_names = {'aarch64': 'ipxe-aa64.efi',
+                      'x86_64': 'ipxe.kpxe'}
+        self.config(ipxe_bootfile_name_by_arch=arch_names, group='pxe')
+        properties = {'cpu_arch': 'aarch64', 'capabilities': 'boot_mode:uefi'}
+        self.node.properties = properties
+        result = utils.get_ipxe_boot_file(self.node)
+        self.assertEqual('ipxe-aa64.efi', result)
+
+    def test_get_ipxe_boot_file_fallback(self):
+        self.config(ipxe_bootfile_name=None, group='pxe')
+        self.config(uefi_ipxe_bootfile_name=None, group='pxe')
+        self.config(pxe_bootfile_name='lolcat', group='pxe')
+        result = utils.get_ipxe_boot_file(self.node)
+        self.assertEqual('lolcat', result)
+
     def test_get_pxe_config_template_emtpy_property(self):
         self.node.properties = {}
         self.config(pxe_config_template_by_arch=self.template_by_arch,
@@ -597,6 +625,28 @@ class GetPxeBootConfigTestCase(db_base.DbTestCase):
         result = utils.get_pxe_config_template(node)
         self.assertEqual('fake-template', result)
 
+    def test_get_ipxe_config_template(self):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware')
+        self.assertIn('ipxe_config.template',
+                      utils.get_ipxe_config_template(node))
+
+    def test_get_ipxe_config_template_none(self):
+        self.config(ipxe_config_template=None, group='pxe')
+        self.config(pxe_config_template='magical_bootloader',
+                    group='pxe')
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware')
+        self.assertEqual('magical_bootloader',
+                         utils.get_ipxe_config_template(node))
+
+    def test_get_ipxe_config_template_override_pxe_fallback(self):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            driver_info={'pxe_template': 'magical'})
+        self.assertEqual('magical',
+                         utils.get_ipxe_config_template(node))
+
 
 @mock.patch('time.sleep', lambda sec: None)
 class OtherFunctionTestCase(db_base.DbTestCase):
@@ -771,19 +821,9 @@ class OtherFunctionTestCase(db_base.DbTestCase):
         mock_clean_up_caches.assert_called_once_with(None, 'master_dir',
                                                      [('uuid', 'path')])
 
-    @mock.patch('ironic.common.keystone.get_auth')
-    @mock.patch.object(utils, '_get_ironic_session')
-    def test_get_ironic_api_url_from_config(self, mock_ks, mock_auth):
-        mock_sess = mock.Mock()
-        mock_ks.return_value = mock_sess
-        fake_api_url = 'http://foo/'
-        self.config(api_url=fake_api_url, group='conductor')
-        # also checking for stripped trailing slash
-        self.assertEqual(fake_api_url[:-1], utils.get_ironic_api_url())
-
-    @mock.patch('ironic.common.keystone.get_auth')
-    @mock.patch.object(utils, '_get_ironic_session')
-    @mock.patch('ironic.common.keystone.get_adapter')
+    @mock.patch('ironic.common.keystone.get_auth', autospec=True)
+    @mock.patch.object(utils, '_get_ironic_session', autospec=True)
+    @mock.patch('ironic.common.keystone.get_adapter', autospec=True)
     def test_get_ironic_api_url_from_keystone(self, mock_ka, mock_ks,
                                               mock_auth):
         mock_sess = mock.Mock()
@@ -791,7 +831,6 @@ class OtherFunctionTestCase(db_base.DbTestCase):
         fake_api_url = 'http://foo/'
         mock_ka.return_value.get_endpoint.return_value = fake_api_url
         # NOTE(pas-ha) endpoint_override is None by default
-        self.config(api_url=None, group='conductor')
         url = utils.get_ironic_api_url()
         # also checking for stripped trailing slash
         self.assertEqual(fake_api_url[:-1], url)
@@ -799,26 +838,24 @@ class OtherFunctionTestCase(db_base.DbTestCase):
                                    auth=mock_auth.return_value)
         mock_ka.return_value.get_endpoint.assert_called_once_with()
 
-    @mock.patch('ironic.common.keystone.get_auth')
-    @mock.patch.object(utils, '_get_ironic_session')
-    @mock.patch('ironic.common.keystone.get_adapter')
+    @mock.patch('ironic.common.keystone.get_auth', autospec=True)
+    @mock.patch.object(utils, '_get_ironic_session', autospec=True)
+    @mock.patch('ironic.common.keystone.get_adapter', autospec=True)
     def test_get_ironic_api_url_fail(self, mock_ka, mock_ks, mock_auth):
         mock_sess = mock.Mock()
         mock_ks.return_value = mock_sess
         mock_ka.return_value.get_endpoint.side_effect = (
             exception.KeystoneFailure())
-        self.config(api_url=None, group='conductor')
         self.assertRaises(exception.InvalidParameterValue,
                           utils.get_ironic_api_url)
 
-    @mock.patch('ironic.common.keystone.get_auth')
-    @mock.patch.object(utils, '_get_ironic_session')
-    @mock.patch('ironic.common.keystone.get_adapter')
+    @mock.patch('ironic.common.keystone.get_auth', autospec=True)
+    @mock.patch.object(utils, '_get_ironic_session', autospec=True)
+    @mock.patch('ironic.common.keystone.get_adapter', autospec=True)
     def test_get_ironic_api_url_none(self, mock_ka, mock_ks, mock_auth):
         mock_sess = mock.Mock()
         mock_ks.return_value = mock_sess
         mock_ka.return_value.get_endpoint.return_value = None
-        self.config(api_url=None, group='conductor')
         self.assertRaises(exception.InvalidParameterValue,
                           utils.get_ironic_api_url)
 
@@ -1115,7 +1152,7 @@ class AgentMethodsTestCase(db_base.DbTestCase):
     @mock.patch('ironic.conductor.utils.node_power_action', autospec=True)
     @mock.patch.object(utils, 'build_agent_options', autospec=True)
     @mock.patch('ironic.drivers.modules.network.flat.FlatNetwork.'
-                'add_cleaning_network')
+                'add_cleaning_network', autospec=True)
     def _test_prepare_inband_cleaning(
             self, add_cleaning_network_mock,
             build_options_mock, power_mock, prepare_ramdisk_mock,
@@ -1127,7 +1164,8 @@ class AgentMethodsTestCase(db_base.DbTestCase):
             self.assertEqual(
                 states.CLEANWAIT,
                 utils.prepare_inband_cleaning(task, manage_boot=manage_boot))
-            add_cleaning_network_mock.assert_called_once_with(task)
+            add_cleaning_network_mock.assert_called_once_with(
+                task.driver.network, task)
             if not fast_track:
                 power_mock.assert_called_once_with(task, states.REBOOT)
             else:
@@ -1153,41 +1191,10 @@ class AgentMethodsTestCase(db_base.DbTestCase):
     def test_prepare_inband_cleaning_fast_track(self):
         self._test_prepare_inband_cleaning(fast_track=True)
 
-    @mock.patch('ironic.conductor.utils.power_on_node_if_needed',
-                autospec=True)
-    @mock.patch('ironic.conductor.utils.is_fast_track', autospec=True)
-    @mock.patch.object(pxe.PXEBoot, 'prepare_ramdisk', autospec=True)
-    @mock.patch('ironic.conductor.utils.node_power_action', autospec=True)
-    @mock.patch.object(utils, 'build_agent_options', autospec=True)
-    @mock.patch('ironic.drivers.modules.network.flat.FlatNetwork.'
-                'add_cleaning_network', autospec=True)
-    def test_prepare_inband_cleaning_broken_fast_track(
-            self, add_cleaning_network_mock,
-            build_options_mock, power_mock, prepare_ramdisk_mock,
-            is_fast_track_mock, power_on_if_needed_mock):
-        build_options_mock.return_value = {'a': 'b'}
-        is_fast_track_mock.side_effect = [True, False]
-        with task_manager.acquire(
-                self.context, self.node.uuid, shared=False) as task:
-            self.assertEqual(
-                states.CLEANWAIT,
-                utils.prepare_inband_cleaning(task))
-            add_cleaning_network_mock.assert_called_once_with(
-                task.driver.network, task)
-            power_mock.assert_called_once_with(task, states.REBOOT)
-            self.assertEqual(1, task.node.driver_internal_info[
-                             'agent_erase_devices_iterations'])
-            self.assertIs(True, task.node.driver_internal_info[
-                          'agent_erase_devices_zeroize'])
-            prepare_ramdisk_mock.assert_called_once_with(
-                mock.ANY, mock.ANY, {'a': 'b'})
-            build_options_mock.assert_called_once_with(task.node)
-            self.assertFalse(power_on_if_needed_mock.called)
-
     @mock.patch('ironic.conductor.utils.is_fast_track', autospec=True)
     @mock.patch.object(pxe.PXEBoot, 'clean_up_ramdisk', autospec=True)
     @mock.patch('ironic.drivers.modules.network.flat.FlatNetwork.'
-                'remove_cleaning_network')
+                'remove_cleaning_network', autospec=True)
     @mock.patch('ironic.conductor.utils.node_power_action', autospec=True)
     def _test_tear_down_inband_cleaning(
             self, power_mock, remove_cleaning_network_mock,
@@ -1203,7 +1210,8 @@ class AgentMethodsTestCase(db_base.DbTestCase):
                 power_mock.assert_called_once_with(task, states.POWER_OFF)
             else:
                 self.assertFalse(power_mock.called)
-            remove_cleaning_network_mock.assert_called_once_with(task)
+            remove_cleaning_network_mock.assert_called_once_with(
+                task.driver.network, task)
             if manage_boot:
                 clean_up_ramdisk_mock.assert_called_once_with(
                     task.driver.boot, task)
@@ -1223,13 +1231,13 @@ class AgentMethodsTestCase(db_base.DbTestCase):
         self._test_tear_down_inband_cleaning(cleaning_error=True)
 
     def test_build_agent_options_conf(self):
-        self.config(api_url='https://api-url', group='conductor')
+        self.config(endpoint_override='https://api-url',
+                    group='service_catalog')
         options = utils.build_agent_options(self.node)
         self.assertEqual('https://api-url', options['ipa-api-url'])
 
-    @mock.patch.object(utils, '_get_ironic_session')
+    @mock.patch.object(utils, '_get_ironic_session', autospec=True)
     def test_build_agent_options_keystone(self, session_mock):
-        self.config(api_url=None, group='conductor')
         sess = mock.Mock()
         sess.get_endpoint.return_value = 'https://api-url'
         session_mock.return_value = sess
@@ -2207,7 +2215,7 @@ class TestStorageInterfaceUtils(db_base.DbTestCase):
 
 
 class InstanceImageCacheTestCase(db_base.DbTestCase):
-    @mock.patch.object(fileutils, 'ensure_tree')
+    @mock.patch.object(fileutils, 'ensure_tree', autospec=True)
     def test_with_master_path(self, mock_ensure_tree):
         self.config(instance_master_path='/fake/path', group='pxe')
         self.config(image_cache_size=500, group='pxe')
@@ -2219,7 +2227,7 @@ class InstanceImageCacheTestCase(db_base.DbTestCase):
         self.assertEqual(500 * 1024 * 1024, cache._cache_size)
         self.assertEqual(30 * 60, cache._cache_ttl)
 
-    @mock.patch.object(fileutils, 'ensure_tree')
+    @mock.patch.object(fileutils, 'ensure_tree', autospec=True)
     def test_without_master_path(self, mock_ensure_tree):
         self.config(instance_master_path='', group='pxe')
         self.config(image_cache_size=500, group='pxe')
