@@ -16,8 +16,8 @@
 """Test class for iPXE driver."""
 
 import os
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils as json
 from oslo_utils import uuidutils
@@ -83,7 +83,6 @@ class iPXEBootTestCase(db_base.DbTestCase):
             driver_internal_info=self.driver_internal_info)
         self.port = obj_utils.create_test_port(self.context,
                                                node_id=self.node.id)
-        self.config(group='conductor', api_url='http://127.0.0.1:1234/')
 
     def test_get_properties(self):
         expected = pxe_base.COMMON_PROPERTIES
@@ -228,7 +227,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
     # and refactored as we begin to separate PXE and iPXE interfaces.
     @mock.patch.object(manager_utils, 'node_get_boot_mode', autospec=True)
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
-    @mock.patch.object(dhcp_factory, 'DHCPFactory')
+    @mock.patch.object(dhcp_factory, 'DHCPFactory', autospec=True)
     @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
     @mock.patch.object(pxe_utils, 'get_image_info', autospec=True)
     @mock.patch.object(pxe_utils, 'cache_ramdisk_kernel', autospec=True)
@@ -310,14 +309,9 @@ class iPXEBootTestCase(db_base.DbTestCase):
                 mock_cache_r_k.assert_called_once_with(
                     task, {'rescue_kernel': 'a', 'rescue_ramdisk': 'r'},
                     ipxe_enabled=True)
-            if uefi:
-                mock_pxe_config.assert_called_once_with(
-                    task, {}, CONF.pxe.uefi_pxe_config_template,
-                    ipxe_enabled=True)
-            else:
-                mock_pxe_config.assert_called_once_with(
-                    task, {}, CONF.pxe.pxe_config_template,
-                    ipxe_enabled=True)
+            mock_pxe_config.assert_called_once_with(
+                task, {}, CONF.pxe.ipxe_config_template,
+                ipxe_enabled=True)
 
     def test_prepare_ramdisk(self):
         self.node.provision_state = states.DEPLOYING
@@ -660,7 +654,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
                                                          boot_devices.PXE,
                                                          persistent=True)
 
-    @mock.patch('os.path.isfile', return_value=False)
+    @mock.patch('os.path.isfile', return_value=False, autospec=True)
     @mock.patch.object(pxe_utils, 'create_pxe_config', autospec=True)
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
     @mock.patch.object(deploy_utils, 'switch_pxe_config', autospec=True)
@@ -700,7 +694,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
                                                ipxe_enabled=True)
             provider_mock.update_dhcp.assert_called_once_with(task, dhcp_opts)
             create_pxe_config_mock.assert_called_once_with(
-                task, mock.ANY, CONF.pxe.pxe_config_template,
+                task, mock.ANY, CONF.pxe.ipxe_config_template,
                 ipxe_enabled=True)
             switch_pxe_config_mock.assert_called_once_with(
                 pxe_config_path, "30212642-09d3-467f-8e09-21685826ab50",
@@ -709,7 +703,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
 
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
     @mock.patch.object(deploy_utils, 'switch_pxe_config', autospec=True)
-    @mock.patch.object(dhcp_factory, 'DHCPFactory')
+    @mock.patch.object(dhcp_factory, 'DHCPFactory', autospec=True)
     @mock.patch.object(pxe_utils, 'cache_ramdisk_kernel', autospec=True)
     @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
     def test_prepare_instance_netboot_missing_root_uuid(
@@ -746,7 +740,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
     @mock.patch.object(pxe_base.LOG, 'warning', autospec=True)
     @mock.patch.object(pxe_utils, 'clean_up_pxe_config', autospec=True)
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
-    @mock.patch.object(dhcp_factory, 'DHCPFactory')
+    @mock.patch.object(dhcp_factory, 'DHCPFactory', autospec=True)
     @mock.patch.object(pxe_utils, 'cache_ramdisk_kernel', autospec=True)
     @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
     def test_prepare_instance_whole_disk_image_missing_root_uuid(
@@ -817,7 +811,7 @@ class iPXEBootTestCase(db_base.DbTestCase):
             self.assertFalse(cache_mock.called)
             provider_mock.update_dhcp.assert_called_once_with(task, dhcp_opts)
             create_pxe_config_mock.assert_called_once_with(
-                task, mock.ANY, CONF.pxe.pxe_config_template,
+                task, mock.ANY, CONF.pxe.ipxe_config_template,
                 ipxe_enabled=True)
             switch_pxe_config_mock.assert_called_once_with(
                 pxe_config_path, None, boot_modes.LEGACY_BIOS, False,
@@ -858,6 +852,41 @@ class iPXEBootTestCase(db_base.DbTestCase):
                 task, ipxe_enabled=True)
             self.assertFalse(set_boot_device_mock.called)
 
+    @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
+    @mock.patch.object(pxe_utils, 'clean_up_pxe_config', autospec=True)
+    @mock.patch.object(deploy_utils, 'switch_pxe_config', autospec=True)
+    @mock.patch.object(dhcp_factory, 'DHCPFactory', autospec=True)
+    @mock.patch.object(pxe_utils, 'cache_ramdisk_kernel', autospec=True)
+    @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
+    def test_prepare_instance_localboot_with_fallback(
+            self, get_image_info_mock, cache_mock,
+            dhcp_factory_mock, switch_pxe_config_mock,
+            clean_up_pxe_config_mock, set_boot_device_mock):
+        self.config(enable_netboot_fallback=True, group='pxe')
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            task.node.instance_info = task.node.instance_info
+            task.node.instance_info['capabilities'] = {'boot_option': 'local'}
+            task.node.driver_internal_info['root_uuid_or_disk_id'] = (
+                "30212642-09d3-467f-8e09-21685826ab50")
+            task.node.driver_internal_info['is_whole_disk_image'] = False
+            pxe_config_path = pxe_utils.get_pxe_config_file_path(
+                task.node.uuid, ipxe_enabled=True)
+
+            task.driver.boot.prepare_instance(task)
+
+            set_boot_device_mock.assert_called_once_with(task,
+                                                         boot_devices.DISK,
+                                                         persistent=True)
+            switch_pxe_config_mock.assert_called_once_with(
+                pxe_config_path, "30212642-09d3-467f-8e09-21685826ab50",
+                'bios', True, False, False, False, ipxe_enabled=True)
+            # No clean up
+            self.assertFalse(clean_up_pxe_config_mock.called)
+            # No netboot configuration beyond the PXE files
+            self.assertFalse(get_image_info_mock.called)
+            self.assertFalse(cache_mock.called)
+            self.assertFalse(dhcp_factory_mock.return_value.update_dhcp.called)
+
     @mock.patch.object(pxe_utils, 'clean_up_pxe_env', autospec=True)
     @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
     def test_clean_up_instance(self, get_image_info_mock,
