@@ -17,8 +17,8 @@
 
 import os
 import tempfile
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils as json
 from oslo_utils import timeutils
@@ -85,7 +85,6 @@ class PXEBootTestCase(db_base.DbTestCase):
             driver_internal_info=self.driver_internal_info)
         self.port = obj_utils.create_test_port(self.context,
                                                node_id=self.node.id)
-        self.config(group='conductor', api_url='http://127.0.0.1:1234/')
         self.config(my_ipv6='2001:db8::1')
 
     def test_get_properties(self):
@@ -225,7 +224,7 @@ class PXEBootTestCase(db_base.DbTestCase):
 
     @mock.patch.object(manager_utils, 'node_get_boot_mode', autospec=True)
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
-    @mock.patch.object(dhcp_factory, 'DHCPFactory')
+    @mock.patch.object(dhcp_factory, 'DHCPFactory', autospec=True)
     @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
     @mock.patch.object(pxe_utils, 'get_image_info', autospec=True)
     @mock.patch.object(pxe_utils, 'cache_ramdisk_kernel', autospec=True)
@@ -277,7 +276,8 @@ class PXEBootTestCase(db_base.DbTestCase):
                                                          mode=mode,
                                                          ipxe_enabled=False)
             provider_mock.update_dhcp.assert_called_once_with(task, dhcp_opts)
-            get_boot_mode_mock.assert_called_once_with(task)
+            if self.node.provision_state == states.DEPLOYING:
+                get_boot_mode_mock.assert_called_once_with(task)
             set_boot_device_mock.assert_called_once_with(task,
                                                          boot_devices.PXE,
                                                          persistent=persistent)
@@ -581,7 +581,7 @@ class PXEBootTestCase(db_base.DbTestCase):
                                                          boot_devices.PXE,
                                                          persistent=True)
 
-    @mock.patch('os.path.isfile', return_value=False)
+    @mock.patch('os.path.isfile', return_value=False, autospec=True)
     @mock.patch.object(pxe_utils, 'create_pxe_config', autospec=True)
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
     @mock.patch.object(deploy_utils, 'switch_pxe_config', autospec=True)
@@ -629,7 +629,7 @@ class PXEBootTestCase(db_base.DbTestCase):
 
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
     @mock.patch.object(deploy_utils, 'switch_pxe_config', autospec=True)
-    @mock.patch.object(dhcp_factory, 'DHCPFactory')
+    @mock.patch.object(dhcp_factory, 'DHCPFactory', autospec=True)
     @mock.patch.object(pxe_utils, 'cache_ramdisk_kernel', autospec=True)
     @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
     def test_prepare_instance_netboot_missing_root_uuid(
@@ -664,7 +664,7 @@ class PXEBootTestCase(db_base.DbTestCase):
     @mock.patch.object(pxe_base.LOG, 'warning', autospec=True)
     @mock.patch.object(pxe_utils, 'clean_up_pxe_config', autospec=True)
     @mock.patch.object(manager_utils, 'node_set_boot_device', autospec=True)
-    @mock.patch.object(dhcp_factory, 'DHCPFactory')
+    @mock.patch.object(dhcp_factory, 'DHCPFactory', autospec=True)
     @mock.patch.object(pxe_utils, 'cache_ramdisk_kernel', autospec=True)
     @mock.patch.object(pxe_utils, 'get_instance_image_info', autospec=True)
     def test_prepare_instance_whole_disk_image_missing_root_uuid(
