@@ -12,7 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 
 from ironic.common import driver_factory
 from ironic.common import exception
@@ -36,7 +36,6 @@ class ManualManagementHardwareTestCase(db_base.DbTestCase):
         self.config(enabled_hardware_types=['manual-management'],
                     enabled_power_interfaces=['fake'],
                     enabled_management_interfaces=['noop', 'fake'])
-        self.config(enabled=True, group='inspector')
 
     def test_default_interfaces(self):
         node = obj_utils.create_test_node(self.context,
