@@ -31,8 +31,8 @@ Current list of mocked libraries:
 
 import importlib
 import sys
+from unittest import mock
 
-import mock
 from oslo_utils import importutils
 
 from ironic.drivers.modules import ipmitool
@@ -173,9 +173,6 @@ if 'ironic.drivers.modules.irmc' in sys.modules:
 irmc_boot = importutils.import_module(
     'ironic.drivers.modules.irmc.boot')
 irmc_boot.check_share_fs_mounted_orig = irmc_boot.check_share_fs_mounted
-irmc_boot.check_share_fs_mounted_patcher = mock.patch(
-    'ironic.drivers.modules.irmc.boot.check_share_fs_mounted')
-irmc_boot.check_share_fs_mounted_patcher.return_value = None
 
 
 class MockKwargsException(Exception):
@@ -234,8 +231,6 @@ if not sushy:
         type('MissingAttributeError', (sushy.exceptions.SushyError,), {}))
     sushy.exceptions.OEMExtensionNotFoundError = (
         type('OEMExtensionNotFoundError', (sushy.exceptions.SushyError,), {}))
-    sushy.exceptions.BadRequestError = (
-        type('BadRequestError', (sushy.exceptions.SushyError,), {}))
     sushy.auth = mock.MagicMock(spec_set=mock_specs.SUSHY_AUTH_SPEC)
     sys.modules['sushy.auth'] = sushy.auth
 
